@@ -33,25 +33,30 @@ class AstromCalibSim():
     Args:
         static_distort : astropy table : table containing the distortions across the field
         
-        centroid_noise_std : float : standard deviation of Gaussian noise applied to centroids.
+        centroid_noise_std : float : standard deviation of Gaussian noise applied to centroids (arcsec).
         
-        hole_position_std  : float : standard deviation of manufacturing error on hole positions.
+        hole_position_std  : float : standard deviation of manufacturing error on hole positions (mm).
         
-        dx : float : shift applied in x direction for calibration process.
+        dx : float : shift applied in x direction for calibration process (mm).
         
-        dy : float : shift applied in y direction for calibration process.
+        dy : float : shift applied in y direction for calibration process (mm).
         
         n_poly : int : maximum order of homogenous bivariate polynomial used to fit distortions.
 
-        pin_pitch : float : distance between pins at input plane (mm)
+        pin_pitch : float : distance between pins at input plane (mm).
 
-        num_pin_x : int : number of pins across the x-dimension (sqrt(num_pins_total))
+        num_pin_x : int : number of pins across the x-dimension (sqrt(num_pins_total)).
 
-        mask_scale : float : arcsec/mm at input plane
+        mask_scale : float : arcsec/mm at input plane.
 
-        pixel_size_as : float : pixel size in arcsec of imager camera
+        pixel_size_as : float : pixel size in arcsec of imager camera.
 
-        pixel_size_mm : float : physical pixel size in mm of imager camera
+        pixel_size_mm : float : physical pixel size in mm of imager camera.
+
+    Attributes:
+        mask_scale : float : arcsec/mm at input plane.
+
+        static_distort : astropy.Table : static distortion input table
     """
     def __init__(self, static_distort, centroid_noise_std=10e-6,
                 hole_position_std=1e-2, dx=0.2, dy=0.2, n_poly=6, pin_pitch=0.5,
